function [ret,x0,str,ts,xts]=pend_inv(t,x,u,flag);
%PEND_INV	is the M-file description of the SIMULINK system named PEND_INV.
%	The block-diagram can be displayed by typing: PEND_INV.
%
%	SYS=PEND_INV(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes PEND_INV to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling PEND_INV with a FLAG of zero:
%	[SIZES]=PEND_INV([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[270,310,770,610])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')


%     Subsystem  'Animation'.

new_system([sys,'/','Animation'])
set_param([sys,'/','Animation'],'Location',[445,59,728,223])

add_block('built-in/Inport',[sys,'/','Animation/in_1'])
set_param([sys,'/','Animation/in_1'],...
		'position',[75,55,95,75])

add_block('built-in/S-Function',[sys,'/','Animation/S-function'])
set_param([sys,'/','Animation/S-function'],...
		'function name','pendani',...
		'parameters','PlotIncrement,sys,cb',...
		'position',[120,53,175,77])
add_line([sys,'/','Animation'],[100,65;115,65])
set_param([sys,'/','Animation'],...
		'Mask Display','plot([-10 10],[0 0],[-2 -2 2 2],[0 1 1 0],[0 3],[1 5])',...
		'Mask Type','Pendulum plot',...
		'Mask Dialogue','Pendulum plot|Plot increment|Simulink system|DC reference signal block title')
set_param([sys,'/','Animation'],...
		'Mask Translate','PlotIncrement = @1; sys= @2; cb = @3;',...
		'Mask Help','Pendulum animation function using Handle graphics.',...
		'Mask Entries','0.1\/''penddemo''\/''Constant''\/')


%     Finished composite block 'Animation'.

set_param([sys,'/','Animation'],...
		'position',[280,50,335,100])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'inputs','3',...
		'position',[195,59,225,91])
add_line(sys,[230,75;275,75])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
